==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/AppleRegistrationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.AppleRegistrationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The configuration settings of the registration for the Apple provider
 * @property clientId The Client ID of the app used for login.
 * @property clientSecretSettingName The app setting name that contains the client secret.
 */
public data class AppleRegistrationArgs(
    public val clientId: Output<String>? = null,
    public val clientSecretSettingName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.web.inputs.AppleRegistrationArgs> {
    override fun toJava(): com.pulumi.azurenative.web.inputs.AppleRegistrationArgs =
        com.pulumi.azurenative.web.inputs.AppleRegistrationArgs.builder()
            .clientId(clientId?.applyValue({ args0 -> args0 }))
            .clientSecretSettingName(clientSecretSettingName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AppleRegistrationArgs].
 */
@PulumiTagMarker
public class AppleRegistrationArgsBuilder internal constructor() {
    private var clientId: Output<String>? = null

    private var clientSecretSettingName: Output<String>? = null

    /**
     * @param value The Client ID of the app used for login.
     */
    @JvmName("fnnuayfvyvodrsys")
    public suspend fun clientId(`value`: Output<String>) {
        this.clientId = value
    }

    /**
     * @param value The app setting name that contains the client secret.
     */
    @JvmName("ljprfcsljmbyvhpq")
    public suspend fun clientSecretSettingName(`value`: Output<String>) {
        this.clientSecretSettingName = value
    }

    /**
     * @param value The Client ID of the app used for login.
     */
    @JvmName("wlujccuimhrfreww")
    public suspend fun clientId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clientId = mapped
    }

    /**
     * @param value The app setting name that contains the client secret.
     */
    @JvmName("qndtxuiqiecydddg")
    public suspend fun clientSecretSettingName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clientSecretSettingName = mapped
    }

    internal fun build(): AppleRegistrationArgs = AppleRegistrationArgs(
        clientId = clientId,
        clientSecretSettingName = clientSecretSettingName,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/AppleRegistrationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.AppleRegistrationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The configuration settings of the registration for the Apple provider
 * @property clientId The Client ID of the app used for login.
 * @property clientSecretSettingName The app setting name that contains the client secret.
 */
public data class AppleRegistrationArgs(
    public val clientId: Output<String>? = null,
    public val clientSecretSettingName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.web.inputs.AppleRegistrationArgs> {
    override fun toJava(): com.pulumi.azurenative.web.inputs.AppleRegistrationArgs =
        com.pulumi.azurenative.web.inputs.AppleRegistrationArgs.builder()
            .clientId(clientId?.applyValue({ args0 -> args0 }))
            .clientSecretSettingName(clientSecretSettingName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AppleRegistrationArgs].
 */
@PulumiTagMarker
public class AppleRegistrationArgsBuilder internal constructor() {
    private var clientId: Output<String>? = null

    private var clientSecretSettingName: Output<String>? = null

    /**
     * @param value The Client ID of the app used for login.
     */
    @JvmName("ppninjjbefmlhmlo")
    public suspend fun clientId(`value`: Output<String>) {
        this.clientId = value
    }

    /**
     * @param value The app setting name that contains the client secret.
     */
    @JvmName("pwfkodpclpqaloby")
    public suspend fun clientSecretSettingName(`value`: Output<String>) {
        this.clientSecretSettingName = value
    }

    /**
     * @param value The Client ID of the app used for login.
     */
    @JvmName("rktqagjliigngmpq")
    public suspend fun clientId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clientId = mapped
    }

    /**
     * @param value The app setting name that contains the client secret.
     */
    @JvmName("jrcqomeosrbwlhjk")
    public suspend fun clientSecretSettingName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clientSecretSettingName = mapped
    }

    internal fun build(): AppleRegistrationArgs = AppleRegistrationArgs(
        clientId = clientId,
        clientSecretSettingName = clientSecretSettingName,
    )
}
